@@ -1,13 +1,14 @@
 import {ErrorNotification, FormField, NotificationType, SlidingPanel} from 'argo-ui';
 import * as React from 'react';
 import {Form, FormApi} from 'react-form';
-import {ProgressPopup} from '../../../shared/components';
-import {Consumer} from '../../../shared/context';
+import {ARGO_WARNING_COLOR, ProgressPopup, Spinner} from '../../../shared/components';
+import {Consumer, ContextApis} from '../../../shared/context';
 import * as models from '../../../shared/models';
 import {services} from '../../../shared/services';
 import {ApplicationRetryOptions} from '../application-retry-options/application-retry-options';
-import {ApplicationManualSyncFlags, ApplicationSyncOptions, SyncFlags} from '../application-sync-options/application-sync-options';
+import {ApplicationManualSyncFlags, ApplicationSyncOptions, FORCE_WARNING, SyncFlags} from '../application-sync-options/application-sync-options';
 import {ApplicationSelector} from '../../../shared/components';
+import {confirmSyncingAppOfApps} from '../utils';
 
 interface Progress {
     percentage: number;
@@ -18,6 +19,35 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
     const [form, setForm] = React.useState<FormApi>(null);
     const [progress, setProgress] = React.useState<Progress>(null);
     const getSelectedApps = (params: any) => apps.filter((_, i) => params['app/' + i]);
+    const [isPending, setPending] = React.useState(false);
+    const syncHandler = (currentForm: FormApi, ctx: ContextApis, applications: models.Application[]) => {
+        const formValues = currentForm.getFormState().values;
+        const replaceChecked = formValues.syncOptions?.includes('Replace=true');
+        const selectedApps = [];
+        const selectedAppOfApps: models.Application[] = [];
+        let containAppOfApps = false;
+
+        for (const key in formValues) {
+            if (key.startsWith('app/') && formValues[key]) {
+                selectedApps.push(applications[parseInt(key.slice(key.lastIndexOf('/') + 1), 10)]);
+            }
+        }
+
+        selectedApps.forEach(app => {
+            if (app.isAppOfAppsPattern) {
+                containAppOfApps = true;
+                selectedAppOfApps.push(app);
+            }
+        });
+
+        if (replaceChecked && containAppOfApps) {
+            confirmSyncingAppOfApps(selectedAppOfApps, ctx, currentForm).then(confirmed => {
+                setPending(confirmed ? true : false);
+            });
+        } else {
+            currentForm.submitForm(null);
+        }
+    };
     return (
         <Consumer>
             {ctx => (
@@ -27,7 +57,8 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
                     onClose={() => hide()}
                     header={
                         <div>
-                            <button className='argo-button argo-button--base' onClick={() => form.submitForm(null)}>
+                            <button className='argo-button argo-button--base' disabled={isPending} onClick={() => syncHandler(form, ctx, apps)}>
+                                <Spinner show={isPending} style={{marginRight: '5px'}} />
                                 Sync
                             </button>{' '}
                             <button onClick={() => hide()} className='argo-button argo-button--base-o'>
@@ -38,16 +69,28 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
                     <Form
                         defaultValues={{syncFlags: []}}
                         onSubmit={async (params: any) => {
+                            setPending(true);
                             const selectedApps = getSelectedApps(params);
+                            const syncFlags = {...params.syncFlags} as SyncFlags;
+                            const force = syncFlags.Force || false;
+                            if (force) {
+                                const confirmed = await ctx.popup.confirm('Synchronize with force?', () => (
+                                    <div>
+                                        <i className='fa fa-exclamation-triangle' style={{color: ARGO_WARNING_COLOR}} /> {FORCE_WARNING} Are you sure you want to continue?
+                                    </div>
+                                ));
+                                if (!confirmed) {
+                                    setPending(false);
+                                    return;
+                                }
+                            }
                             if (selectedApps.length === 0) {
                                 ctx.notifications.show({content: `No apps selected`, type: NotificationType.Error});
+                                setPending(false);
                                 return;
                             }
 
-                            const syncFlags = {...params.syncFlags} as SyncFlags;
-
-                            const syncStrategy: models.SyncStrategy =
-                                syncFlags.ApplyOnly || false ? {apply: {force: syncFlags.Force || false}} : {hook: {force: syncFlags.Force || false}};
+                            const syncStrategy: models.SyncStrategy = syncFlags.ApplyOnly || false ? {apply: {force}} : {hook: {force}};
 
                             setProgress({percentage: 0, title: 'Starting...'});
                             let i = 0;
@@ -55,6 +98,7 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
                                 await services.applications
                                     .sync(
                                         app.metadata.name,
+                                        app.metadata.namespace,
                                         app.spec.source.targetRevision,
                                         syncFlags.Prune || false,
                                         syncFlags.DryRun || false,
@@ -68,6 +112,9 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
                                             content: <ErrorNotification title={`Unable to sync ${app.metadata.name}`} e={e} />,
                                             type: NotificationType.Error
                                         });
+                                    })
+                                    .finally(() => {
+                                        setPending(false);
                                     });
                                 i++;
                                 setProgress({
@@ -94,10 +141,11 @@ export const ApplicationsSyncPanel = ({show, apps, hide}: {show: boolean; apps:
                                                 formApi.setTouched('syncOptions', true);
                                                 formApi.setValue('syncOptions', opts);
                                             }}
+                                            id='applications-sync-panel'
                                         />
                                     </div>
 
-                                    <ApplicationRetryOptions formApi={formApi} />
+                                    <ApplicationRetryOptions id='applications-sync-panel' formApi={formApi} />
 
                                     <ApplicationSelector apps={apps} formApi={formApi} />
                                 </div>
